@@ -1,7 +1,7 @@
 context("Test  7: initialisation of EWMA")
 
 library(Rcpp)
-test_that("init EWMA (r fails)", {
+test_that("init 'EWMA' (r fails)", {
 
         expect_error(ewmacd1 <- initEWMAMeanCD(r="A", L=3.00, BL=50), " r ")
         expect_error(ewmacd1 <- initEWMAMeanCD(r="A", L=3.00, BL=50), " not a finite ")
@@ -23,7 +23,7 @@ test_that("init EWMA (r fails)", {
         })
 
 
-test_that("init EWMA (L fails)", {
+test_that("init 'EWMA' (L fails)", {
 
         expect_error(ewmacd1 <- initEWMAMeanCD(r=0.25, L="A", BL=50), " L ")
         expect_error(ewmacd1 <- initEWMAMeanCD(r=0.25, L="A", BL=50), "not a finite")
@@ -39,7 +39,7 @@ test_that("init EWMA (L fails)", {
         })
 
 
-test_that("EWMA init (BL)", {
+test_that("'EWMA' init (BL)", {
         #should FAIL - BL not in range 
         expect_error(ewmacd1 <- initEWMAMeanCD(r=0.25, L=3.00, BL=-1), "BL")
         expect_error(ewmacd1 <- initEWMAMeanCD(r=0.25, L=3.00, BL=-1), "not greater than")
@@ -47,7 +47,7 @@ test_that("EWMA init (BL)", {
 
 
 
-test_that("EWMA init (passes)", {
+test_that("'EWMA' init (passes)", {
         #should pass
         expect_error(ewmacd1 <- initEWMAMeanCD(r=0.25, L=3.00, BL=50), NA)
 
